<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Empreendimento;
use App\Models\Banner;
use App\Models\Midia;
use App\Models\Lead;
use App\Models\Beneficio;

class HomeController extends Controller
{
    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index(Request $request, $ref = null)
    {
        $host = request()->getHost();
        $partes = explode('.', $host);
        $subdominio = $partes[0];

        if (count($partes) > 2 && $subdominio != 'app' && $subdominio != 'imob' && $subdominio != 'imobtask') {
            $empreendimento = Empreendimento::where('url', $subdominio)->first();
            if($empreendimento){
                $favicon = $empreendimento->favicon;
                $logo = $empreendimento->logo;
                $video = $empreendimento->video;
                $banners = Banner::where('empreendimento_id', $empreendimento->id)->orderBy('ordem', 'asc')->get();
                function detectarPlataforma($url) {
                    if (preg_match('/(youtube\.com\/watch\?v=|youtu\.be\/)/', $url)) {
                        return 'YouTube';
                    }
                    if (preg_match('/vimeo\.com\//', $url)) {
                        return 'Vimeo';
                    }
                    return 'Desconhecido';
                }
                $plataforma = detectarPlataforma($video);
                if($plataforma == 'YouTube'){
                    $id_youtube = explode("v=", "$video");
                    $video_url = ' <iframe src="https://www.youtube.com/embed/'.$id_youtube[1].'" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen="" frameborder="0"></iframe>';
                }elseif($plataforma == 'Vimeo'){
                    $id_vimeo = explode(".com/", "$video");
                    $video_url = '<iframe class="vimeo-iframe" data-original-url="https://vimeo.com/'.$id_vimeo[1].'" src="https://player.vimeo.com/video/'.$id_vimeo[1].'" allow="fullscreen" allowfullscreen="" frameborder="0"></iframe>';
                }else{
                    $video_url = '';
                }

                $midias = Midia::where('empreendimento_id', $empreendimento->id)->where('tipo', 'galeria')->paginate(6);
                $total_midias = Midia::where('empreendimento_id', $empreendimento->id)->where('tipo', 'galeria')->count();

                if (isset($ref) && $ref != null) {
                    $promotor = User::where('ref', $ref)
                        ->where('empreendimento_id', $empreendimento->id)
                        ->first();
                    if ($promotor) {
                        $promotor_id = $promotor->id;
                        $facebook = $promotor->facebook ? $promotor->facebook : 'no';
                        $instagram = $promotor->instagram ? $promotor->instagram : 'no';
                        $linkedin = $promotor->linkedin ? $promotor->linkedin : 'no';
                    } else {
                        $prommotor_id = '';
                        $facebook = 'no';
                        $instagram = 'no';
                        $linkedin = 'no';
                    }
                } else {
                    $promotor_id = '';
                    $facebook = 'no';
                    $instagram = 'no';
                    $linkedin = 'no';
                }

                $beneficios = Beneficio::where('empreendimento_id', $empreendimento->id)->get();

                return view('home', compact('empreendimento', 'favicon', 'logo', 'banners', 'plataforma', 'video_url', 'midias', 'total_midias', 'promotor_id', 'beneficios', 'facebook', 'instagram', 'linkedin'));
            }else{
                abort(404);
            }
        
        }else{
            return redirect('https://app.imobtask.com.br');
        }
        
    }

    public function carregarMidias(Request $request)
    {
        $empreendimento_id = $request->empreendimento;
        $page = $request->get('page', 1);
        $midias = Midia::where('empreendimento_id', $empreendimento_id)->where('tipo', 'galeria')->paginate(6, ['*'], 'page', $page);
        return response()->json($midias);
    }

    public function new_lead(Request $request){
        $host = request()->getHost();
        $partes = explode('.', $host);
        $subdominio = $partes[0];
        if (count($partes) > 2 && $subdominio != 'app' && $subdominio != 'imob' && $subdominio != 'imobtask') {
            $empreendimento = Empreendimento::where('url', $subdominio)->first();
            if($empreendimento){
                $promotor = isset($request->promotor) ? $request->promotor : '';
                if($promotor != ''){
                    $prommotor_id = $promotor;
                }else{
                    $promotor = User::where('empreendimento_id', $empreendimento->id)
                        ->inRandomOrder()
                        ->first();
                    
                    $promotor_id = $promotor->id;
                }

                $email_exist = Lead::where('empreendimento_id', $empreendimento->id)->where('email', $request->email)->first();
                if($email_exist){
                    return response()->json(['success' => false, 'message' => 'Endereço de e-mail já cadastrado, tente com outro.']);
                }

                $lead = new Lead;
                $lead->empreendimento_id = $empreendimento->id;
                $lead->promotor_id = $promotor_id;
                $lead->nome = $request->nome;
                $lead->email = $request->email;
                $lead->telefone = $request->telefone;
                $lead->save();

                return response()->json(['success' => true]);
            }
        }

    }
    

    
}
